*! pwigls Version 1.1  Dan_Blanchette@unc.edu  & Kim Chantala 28Apr2011  
*! the carolina population center, unc-ch
** made it so that if the fsu_wt variable has missing values 
**  then the weight variables are created correctly.
** pwigls Version 1.0  Dan_Blanchette@unc.edu  & Kim Chantala 30Sep2005  

program pwigls, nclass 
	version 8
	syntax  [if] [in], psu_id(varlist) fsu_id(varlist) psu_wt(varname numeric) ///
                         fsu_wt(varname numeric)  ///
			[ psu_m1wt(name) fsu_m1wt(name) ///
                          psu_m2wt(name) fsu_m2wt(name) summ ]
                         // uss_wt(name) sum_wt(name) n_sample(name) ]



	marksample touse, novarlist
	quietly count  if `touse'
		if r(N) == 0 error 2000

	if "`psu_m1wt'" == ""  local psu_m1wt = "psu_m1wt" 
	if "`fsu_m1wt'" == ""  local fsu_m1wt = "fsu_m1wt" 
	if "`psu_m2wt'" == ""  local psu_m2wt = "psu_m2wt" 
	if "`fsu_m2wt'" == ""  local fsu_m2wt = "fsu_m2wt" 
/***
	if "`uss_wt'"   == ""  local uss_wt   = "uss_wt" 
	if "`sum_wt'"   == ""  local sum_wt   = "sum_wt" 
	if "`n_sample'" == ""  local n_sample = "n_sample" 
***/
        tempvar uss_wt sum_wt n_sample


	capture confirm variable `psu_m1wt'
	if _rc == 0  local badvars "`psu_m1wt'"
	capture confirm variable `fsu_m1wt'
	if _rc == 0  local badvars "`badvars' `fsu_m1wt'"
	capture confirm variable `psu_m2wt'
	if _rc == 0  local badvars "`badvars' `psu_m2wt'"
	capture confirm variable `fsu_m2wt'
	if _rc == 0  local badvars "`badvars' `fsu_m2wt'"
/****
	capture confirm variable `uss_wt'
	if _rc == 0  local badvars "`badvars' `uss_wt'"
	capture confirm variable `sum_wt'
	if _rc == 0  local badvars "`badvars' `sum_wt'"
	capture confirm variable `n_sample'
	if _rc == 0  local badvars "`badvars' `n_sample'"
****/

	if "`badvars'" != ""  {
		di as error "These variables are created in this program so either drop them or rename them: " 
		di as text "`badvars'"
		di as result "{stata drop `badvars':click here} to drop `badvars'"
		exit 198
	}
	
	foreach wt of varlist `fsu_wt' `psu_wt' {
		quietly count  if `wt' == 0
		if r(N) > 0 {
			di as error _n "WARNING: Your sample weight `wt' contains zero values." _n
		}
	}

	quietly {
	
		egen double `sum_wt' = sum(`fsu_wt')  if `touse' ,  by(`psu_id') 
	
		egen double `uss_wt' = sum(`fsu_wt'^2)  if `touse' ,  by(`psu_id')
	
		egen double `n_sample' = count(`fsu_wt')  if `touse',  by(`psu_id')
	
		label var `sum_wt'   "Sum of `fsu_wt' for `psu_id'" 
		label var `uss_wt'   "Sum of `fsu_wt'*`fsu_wt' for `psu_id'" 
		label var `n_sample' "Number of `fsu_id' in `psu_id'" 
                
		gen double `psu_m1wt' = `uss_wt' / `sum_wt'  if `touse' & `sum_wt' != 0
		label var `psu_m1wt' "Scaled weight for `psu_id' (Level 2 - PWIGLS Method 1)"
	
		gen double `psu_m2wt' = `sum_wt' / `n_sample'  if `touse' & `sum_wt' != 0 
		label var `psu_m2wt' "Scaled weight for `psu_id' (Level 2 - PWIGLS Method 2)"
	
		gen double `fsu_m1wt' = `fsu_wt' / `psu_m1wt'  if `touse'
		label var `fsu_m1wt' "Scaled weight for `fsu_id' (Level 1 - PWIGLS Method 1)"
	
		gen double `fsu_m2wt' = `fsu_wt' / `psu_m2wt'  if `touse'
		label var `fsu_m2wt' "Scaled weight for `fsu_id' (Level 1 - PWIGLS Method 2)"

	}
	
       if "`summ'" != "" {
	 summarize  `psu_wt' `fsu_wt' `psu_m1wt' `fsu_m1wt' `psu_m2wt' `fsu_m2wt' `uss_wt' `sum_wt' `n_sample'
         di as res "`uss_wt' is uss_wt"
         di as res "`sum_wt' is sum_wt"
         di as res "`n_sample' is n_sample"
       }
end
